from calendar import monthrange
from datetime import datetime

from cubicweb.web.views.urlrewrite import SimpleReqRewriter, rgx

class BlogReqRewriter(SimpleReqRewriter):
    rules = [
        (rgx('/blogentry/([a-z_]+)'),
         dict(rql='Any X ORDERBY CD DESC WHERE X is BlogEntry, X creation_date CD, X created_by U, U login "%(user)s"' % {'user': r'\1'},
              user = r'\1')),
        (rgx('/blogentry/([a-z_]+)\.rss'),
         dict(rql='Any X ORDERBY CD DESC LIMIT 20 WHERE X is BlogEntry, X creation_date CD, X created_by U, U login "%(user)s"' % {'user': r'\1'}, vid='rss')),
        (rgx('/blogentries/([0-9]{4})'),
         dict(rql='Any B ORDERBY CD DESC WHERE B is BlogEntry, B creation_date CD, '
                  'B creation_date >= "%(param)s-01-01", '
                  'B creation_date <= "%(param)s-12-31"' % {'param': r'\1'},
              )),
        (rgx('/blogentries/([0-9]{4})/([0-9]{2})'),
         dict(rql='Any B, BD ORDERBY BD DESC '
                  'WHERE B is BlogEntry, B creation_date BD, '
                  'B creation_date >=  "%(year)s/%(month)s/01", B creation_date <= "%(year)s/%(month)s/30"' % {'year': r'\1', 'month': r'\2'},
              )),
        (rgx('/blog/([0-9]+)/blogentries'),
         dict(rql='Any B ORDERBY CD DESC WHERE B is BlogEntry, B creation_date CD, '
                  'B entry_of BL, BL eid %(eid)s' % {'eid': r'\1'},
              )),
        (rgx('/blog/([0-9]+)/blogentries/([0-9]{4})'),
         dict(rql='Any B ORDERBY CD DESC WHERE B is BlogEntry, B creation_date CD, '
                  'B creation_date >= "%(param)s-01-01", '
                  'B creation_date <= "%(param)s-12-31", B entry_of BL, BL eid %(eid)s' % {'eid': r'\1', 'param': r'\2'},
              )),
        (rgx('/blog/([0-9]+)/blogentries/([0-9]{4})/([0-9]{2})'),
         dict(rql='Any B, BD ORDERBY BD DESC '
                  'WHERE B is BlogEntry, B creation_date BD, B entry_of BL, BL eid %(eid)s, '
                  'B creation_date >=  "%(year)s/%(month)s/01", B creation_date <= "%(year)s/%(month)s/30"' % {'eid': r'\1', 'year': r'\2', 'month': r'\3'},
              )),

        ]



"""Primary views for blogs

:organization: Logilab
:copyright: 2003-2010 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
:contact: http://www.logilab.fr/ -- mailto:contact@logilab.fr
"""
__docformat__ = "restructuredtext en"


from logilab.mtconverter import xml_escape

from cubicweb.utils import UStringIO
from cubicweb.selectors import implements
from cubicweb.web import uicfg
from cubicweb.web.views import primary

uicfg.primaryview_section.tag_attribute(('Blog', 'title'), 'hidden')
uicfg.primaryview_section.tag_attribute(('Blog', 'rss_url'), 'hidden')
uicfg.primaryview_section.tag_attribute(('BlogEntry', 'title'), 'hidden')
uicfg.primaryview_section.tag_object_of(('*', 'entry_of', 'Blog'), 'hidden')
uicfg.primaryview_section.tag_subject_of(('BlogEntry', 'entry_of', '*'),
                                         'relations')

uicfg.actionbox_appearsin_addmenu.tag_object_of(('*', 'entry_of', 'Blog'), True)


class BlogPrimaryView(primary.PrimaryView):
    __select__ = implements('Blog')

    def render_entity_attributes(self, entity):
        super(BlogPrimaryView, self).render_entity_attributes(entity)
        self.w('<a class="right" href="%s">%s <img src="%s" alt="%s"/></a>' % (
            xml_escape(entity.rss_feed_url()), self._cw._(u'subscribe'),
            self._cw.external_resource('RSS_LOGO_16'), self._cw._('rss icon')))

    def render_entity_relations(self, entity):
        super(BlogPrimaryView, self).render_entity_relations(entity)
        rset = entity.related('entry_of', 'object')
        if rset:
            strio = UStringIO()
            self.paginate(self._cw, w=strio.write, page_size=10, rset=rset)
            self.wview('sameetypelist', rset)
            self.w(strio.getvalue())

    def render_entity_title(self, entity):
        self.w(u'<h1>%s</h1>' % xml_escape(entity.dc_title()))


class BlogEntryPrimaryView(primary.PrimaryView):
    __select__ = implements('BlogEntry')
    show_attr_label = False

    def render_entity_title(self, entity):
        self.w(u'<h1>%s</h1>' % xml_escape(entity.dc_title()))

    def render_entity_relations(self, entity):
        rset = entity.related('entry_of', 'subject')
        if rset:
            self.w(self._cw._('blogged in '))
            self.wview('csv', rset, 'null')



"""entity classes for Blog entities

:organization: Logilab
:copyright: 2003-2010 LOGILAB S.A. (Paris, FRANCE)
:contact: http://www.logilab.fr/ -- mailto:contact@logilab.fr
:license: Lesser General Public License version 2 or above - http://www.gnu.org/
"""
__docformat__ = "restructuredtext en"

from logilab.common.date import todate

from cubicweb.entities import AnyEntity, fetch_config
from cubicweb.interfaces import (ICalendarViews, ICalendarable,
                                 ISiocItem, ISiocContainer, IPrevNext)


class Blog(AnyEntity):
    """customized class for Blog entities"""

    __regid__ = 'Blog'
    __implements__ = AnyEntity.__implements__ + (ISiocContainer,)

    def rss_feed_url(self):
        if self.rss_url:
            return self.rss_url
        rql = ('Any E ORDERBY D DESC '
               'WHERE E is BlogEntry, E entry_of X, X eid %s, E creation_date D'
               )
        return self._cw.build_url(rql=rql % self.eid, vid='rss',
                              vtitle=self.dc_title())

    # isioc interface ##########################################################

    def isioc_type(self):
        return 'Weblog'

    def isioc_items(self):
        return self.reverse_entry_of


class BlogEntry(AnyEntity):
    """customized class for BlogEntry entities"""
    __regid__ = 'BlogEntry'
    fetch_attrs, fetch_order = fetch_config(['creation_date', 'title'], order='DESC')
    __implements__ = AnyEntity.__implements__ + (
        ICalendarViews, ICalendarable, ISiocItem, IPrevNext)

    def dc_title(self):
        return self.title

    def dc_description(self, format='text/plain'):
        return self.printable_value('content', format=format)

    def dc_date(self, date_format=None):# XXX default to ISO 8601 ?
        """return latest modification date of this entity"""
        return self._cw.format_date(self.creation_date, date_format=date_format)

    def parent(self):
        return self.entry_of and self.entry_of[0] or None

    # calendar interfaces ######################################################

    @property
    def start(self):
        return self.creation_date

    @property
    def stop(self):
        return self.creation_date

    def matching_dates(self, begin, end):
        """calendar views interface"""
        mydate = self.creation_date
        if not mydate:
            return []
        mydate = todate(mydate)
        if begin < mydate < end:
            return [mydate]
        return []

    def postinfo_description(self):
        _ = self._cw._
        descr = u'%s %s' % (_('posted on'), self._cw.format_date(self.creation_date))
        return descr

    # isioc interface ##########################################################

    def isioc_content(self):
        return self.content

    def isioc_container(self):
        return self.parent()

    def isioc_type(self):
        return 'BlogPost'

    def isioc_replies(self):
        # XXX link to comments
        return []

    def isioc_topics(self):
        # XXX link to tags, folders?
        return []

    # IPrevNext interface #####################################################
    def _sibling_entry(self, order, operator):
        if self.entry_of:
            rql = ('Any B ORDERBY B %s LIMIT 1 '
                   'WHERE B is BlogEntry, B entry_of BL, BL eid %%(blog)s, '
                   'B eid %s %%(eid)s')
            rset = self._cw.execute(rql % (order, operator),
                                    {'blog': self.entry_of[0].eid, 'eid': self.eid})
        else:
            rql = ('Any B ORDERBY B %s LIMIT 1 '
                   'WHERE B is BlogEntry, B eid %s %%(eid)s')
            rset = self._cw.execute(rql % (order, operator), {'eid': self.eid})
        if rset:
            return rset.get_entity(0,0)

    def next_entity(self):
        return self._sibling_entry('ASC', '>')

    def previous_entity(self):
        return self._sibling_entry('DESC', '<')



"""Blog unit tests"""

from logilab.common.testlib import unittest_main
from cubicweb.devtools.testlib import CubicWebTC, MAILBOX


class BlogTestsCubicWebTC(CubicWebTC):
    """test blog specific behaviours"""

    def test_notifications(self):
        req = self.request()
        cubicweb_blog = req.create_entity('Blog', title=u'cubicweb',
                                          description=u"cubicweb c'est beau")
        blog_entry_1 = req.create_entity('BlogEntry', title=u"hop", content=u"cubicweb hop")
        blog_entry_1.set_relations(entry_of=cubicweb_blog)
        blog_entry_2 = req.create_entity('BlogEntry', title=u"yes",  content=u"cubicweb yes")
        blog_entry_2.set_relations(entry_of=cubicweb_blog)
        self.assertEquals(len(MAILBOX), 0)
        self.commit()
        self.assertEquals(len(MAILBOX), 0)
        blog_entry_1.fire_transition('publish')
        self.commit()
        self.assertEquals(len(MAILBOX), 1)
        mail = MAILBOX[0]
        self.assertEquals(mail.subject, '[data] hop')
        blog_entry_2.fire_transition('publish')
        self.commit()
        self.assertEquals(len(MAILBOX), 2)
        mail = MAILBOX[1]
        self.assertEquals(mail.subject, '[data] yes')


if __name__ == '__main__':
    unittest_main()



# add group "owners" in transition "publish" of BlogEntry workflow permissions
rql('SET T require_group G WHERE G name "owners", T transition_of W, '
    'T name "publish", W workflow_of ET, ET name "BlogEntry"')
commit()



from cubicweb.selectors import implements, is_in_state
from cubicweb.sobjects.notification import NotificationView, StatusChangeMixIn

class BlogEntryPublishedView(StatusChangeMixIn, NotificationView):
    """get notified from published blogs"""
    __select__ = implements('BlogEntry',) & is_in_state('published')
    content_attr = 'content'

    def subject(self):
        entity = self.cw_rset.get_entity(0, 0)
        return '[%s] %s' % (self._cw.vreg.config.appid, entity.dc_title())



add_relation_definition('BlogEntry',  'in_state', 'State')
add_relation_definition('TrInfo',  'wf_info_for', 'BlogEntry')
add_relation_definition('BlogEntry',  'custom_workflow', 'Workflow')


# add BlogEntry workflow
if confirm('add blog entry workflow'):
    bwf = add_workflow(_('default BlogEntry workflow'), 'BlogEntry')

    draft = bwf.add_state(_('draft'), initial=True)
    published = bwf.add_state(_('published'))

    publish = bwf.add_transition(_('publish'), draft, published,
                                 ('managers',))
    commit()

# set state to published for already existing blog entries
blogentries = rql('Any B WHERE B is BlogEntry')

for eid, in blogentries:
    session.unsafe_execute('SET B in_state S WHERE S name "published", '
                           'S state_of WF, WF name "default BlogEntry workflow", '
                           'B eid %(b)s',
                           {'b': eid}, 'b')

commit()



"""Secondary views for blogs

:organization: Logilab
:copyright: 2003-2010 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
:contact: http://www.logilab.fr/ -- mailto:contact@logilab.fr
"""
__docformat__ = "restructuredtext en"

from calendar import monthrange
from datetime import datetime

from logilab.mtconverter import xml_escape

from cubicweb.schema import display_name
from cubicweb.view import EntityView, StartupView
from cubicweb.selectors import paginated_rset, sorted_rset, implements, \
                               authenticated_user
from cubicweb.web.htmlwidgets import BoxLink, BoxWidget
from cubicweb.web.views import baseviews, boxes, calendar, navigation, workflow

class BlogEntryArchiveView(StartupView):
    """control the view of a blog archive"""
    __regid__ = 'blog_archive'
    countrql = 'Any COUNT(B) WHERE B is BlogEntry, B creation_date >=  %(firstday)s, B creation_date <= %(lastday)s'

    def represent(self, items, year, month):
        """represent a single month entry"""
        firstday = datetime(year, month, 1)
        lastday = datetime(year, month, monthrange(year, month)[1])
        rql = ('Any B, BD ORDERBY BD DESC '
               'WHERE B is BlogEntry, B creation_date BD, '
               'B creation_date >=  "%s", B creation_date <= "%s"' %
                (firstday.strftime('%Y-%m-%d'), lastday.strftime('%Y-%m-%d')))
        args = {'firstday':firstday, 'lastday':lastday}
        nmb_entries = self._cw.execute(self.countrql, args)[0][0]
        label = u'%s %s [%s]' % (self._cw._(calendar.MONTHNAMES[month-1]), year,
                                 nmb_entries)
        vtitle = '%s %s' % (display_name(self._cw, 'BlogEntry', 'plural'), label)
        url = xml_escape(self._cw.build_url('view', rql=rql, month=month, year=year, vtitle=vtitle))
        link = u'<a href="%s" title="">%s</a>' % (url, label)
        items.append( u'<li class="">%s</li>\n' % link )

    def call(self, maxentries=None, **kwargs):
        """display a list of entities by calling their <item_vid> view
        """
        rset = self._cw.execute('Any CD ORDERBY CD DESC WHERE B is BlogEntry, B creation_date CD')

        blogmonths = []
        items = []
        for (blogdate,) in rset:
            year, month = blogdate.year, blogdate.month
            if (year, month) not in blogmonths:
                blogmonths.append( (year, month) )
        if maxentries is None:
            displayed_months = blogmonths
            needmore = False
        else:
            needmore = len(blogmonths) > maxentries
            displayed_months = blogmonths[:maxentries]
        for year, month in displayed_months:
            self.represent(items, year, month)
        if needmore:
            url = self._cw.build_url('view', vid='blog_archive')
            link = u'<a href="%s" title="">[%s]</a>' % (url, self._cw._('see more archives'))
            items.append( u'<li class="">%s</li>\n' % link )
        self.w(u'<div class="boxFrame">')
        if items:
            self.w(u'<div class="boxContent">\n')
            self.w(u'<ul class="boxListing">')
            self.w(''.join(items))
            self.w(u'</ul>\n</div>\n')
        self.w(u'</div>')


class BlogEntryArchiveBox(boxes.BoxTemplate):
    """blog side box displaying a Blog Archive"""
    __regid__ = 'blog_archives_box'
    title = _('boxes_blog_archives_box')
    order = 35

    def call(self, **kwargs):
        """display blogs archive"""
        # XXX turn into a selector
        count_blogentry = self._cw.execute('Any COUNT(B) WHERE B is BlogEntry')
        if count_blogentry[0][0] > 0:
            box = BoxWidget(self._cw._(self.title), id=self.__regid__, islist=False)
            box.append(boxes.BoxHtml(self._cw.view('blog_archive', None, maxentries=12)))
            box.render(self.w)


class BlogEntryListBox(boxes.BoxTemplate):
    """display a box with latest blogs and rss"""
    __regid__ = 'blog_latest_box'
    title = _('blog_latest_box')
    visible = True # enabled by default
    order = 34

    def call(self, view=None, **kwargs):
        # XXX turn into a selector
        rset = self._cw.execute('Any X,T,CD ORDERBY CD DESC LIMIT 5 '
                                'WHERE X is BlogEntry, X title T, '
                                'X creation_date CD')
        if not rset:
            return
        box = BoxWidget(self._cw._(self.title), self.__regid__, islist=True)
        # TODO - get the date between brakets after link
        # empty string for title argument to deactivate auto-title
        for i in xrange(rset.rowcount):
            entity = rset.get_entity(i, 0)
            box.append(BoxLink(entity.absolute_url(), xml_escape(entity.dc_title())))
        rqlst = rset.syntax_tree()
        rqlst.set_limit(None)
        rql = rqlst.as_string(kwargs=rset.args)
        url = self._cw.build_url('view', rql=rql, page_size=10)
        box.append(BoxLink(url,  u'[%s]' % self._cw._(u'see more')))
        rss_icon = self._cw.external_resource('RSS_LOGO_16')
        # FIXME - could use rss_url defined as a property if available
        rss_label = u'%s <img src="%s" alt="%s"/>' % (
            self._cw._(u'subscribe'), rss_icon, self._cw._('rss icon'))
        rss_url = self._cw.build_url('view', vid='rss', rql=rql)
        box.append(BoxLink(rss_url, rss_label))
        box.render(self.w)


class BlogEntrySummary(boxes.BoxTemplate):
    __regid__ = 'blog_summary_box'
    title = _('boxes_blog_summary_box')
    order = 36
    __select__ = boxes.BoxTemplate.__select__

    def call(self, view=None, **kwargs):
        box = BoxWidget(self._cw._(self.title), self.__regid__, islist=True)
        rql = 'Any U, COUNT(B) GROUPBY U WHERE U is CWUser, ' \
              'B is BlogEntry, B created_by U'
        rset = self._cw.execute(rql)
        for user in rset:
            euser = self._cw.entity_from_eid(user[0])
            box.append(BoxLink(self._cw.build_url('blogentry/%s' % euser.login),
                                              u'%s [%s]' % (euser.name(),
                                                            user[1])))
        box.render(self.w)

## list views ##################################################################

class BlogEntrySameETypeListView(baseviews.SameETypeListView):
    __select__ = baseviews.SameETypeListView.__select__ & implements('BlogEntry')
    countrql = 'Any COUNT(B) WHERE B is BlogEntry, B creation_date >=  %(firstday)s, B creation_date <= %(lastday)s'
    item_vid = 'blog'

    def call(self, **kwargs):
        self._cw.add_css('cubes.blog.css')
        super(BlogEntrySameETypeListView, self).call(**kwargs)
        if 'year' in self._cw.form and 'month' in self._cw.form:
            self.render_next_previous(int(self._cw.form['year']), int(self._cw.form['month']))

    def render_next_previous(self, year, month):
        if month == 12:
            nextmonth = 1
            year = year + 1
        else:
            nextmonth = month + 1
        if month == 1:
            previousmonth = 12
            year = year - 1
        else:
            previousmonth = month -1

        self.w(u'<div class="prevnext">')
        self.w(u'<span class="previousmonth">%s</span>' \
               % self.render_link(year, previousmonth,
                                  xml_escape(u'<< ' + self._cw._(u'previous month'))))
        self.w(u'<span class="nextmonth">%s</span>' \
               % self.render_link(year, nextmonth,
                                  xml_escape(self._cw._(u'next month') + u' >>')))
        self.w(u'</div>')

    def render_link(self, year, month, atitle):
        firstday = datetime(year, month, 1)
        lastday = datetime(year, month, monthrange(year, month)[1])
        rql = ('Any B, BD ORDERBY BD DESC '
               'WHERE B is BlogEntry, B creation_date BD, '
               'B creation_date >=  "%s", B creation_date <= "%s"' %
                (firstday.strftime('%Y-%m-%d'), lastday.strftime('%Y-%m-%d')))
        args = {'firstday':firstday, 'lastday':lastday}
        nmb_entries = self._cw.execute(self.countrql, args)[0][0]
        label = u'%s %s [%s]' % (self._cw._(calendar.MONTHNAMES[month-1]), year,
                                 nmb_entries)
        vtitle = '%s %s' % (display_name(self._cw, 'BlogEntry', 'plural'), label)
        url = xml_escape(self._cw.build_url('view', rql=rql, vtitle=vtitle,
                                        month=month, year=year))
        if self._cw.execute(rql):
            return u'<a href="%s" title="">%s</a>' % (url, atitle)
        return u''


class BlogEntryBlogView(EntityView):
    __regid__ = 'blog'
    __select__ = implements('BlogEntry')

    def cell_call(self, row, col):
        entity = self.cw_rset.get_entity(row, col)
        w = self.w
        _ = self._cw._
        w(u'<div class="post">')
        w(u'<h1>%s</h1>' % entity.view('incontext'))
        w(u'<div class="creation_date">%s</div>' %
          self._cw.format_date(entity.creation_date))
        creator = entity.creator
        if creator:
            vtitle = _('blog entries created by %s') % creator.name()
            rql = 'Any X ORDERBY D DESC WHERE X is BlogEntry, X created_by Y, '\
                  'Y eid %s, X creation_date D' % creator.eid
            url = self._cw.build_url('view', rql=rql, vtitle=vtitle, page_size=10)
            w(u'<span class="author">%s <a title="%s" href="%s">%s</a></span>' % (
                _('by'), xml_escape(vtitle), xml_escape(url), creator.name()))
        w(u'<div class="entry">')
        body = entity.printable_value('content')
        w(body)
        w(u'</div>')
        w(u'<br class="clear"/>')
        w(u'<div class="postmetadata">%s</div>' % entity.view('post-reldata'))
        w(u'</div>')


class BlogEntryPostMetaData(EntityView):
    __regid__ = 'post-reldata'
    __select__ = implements('BlogEntry')

    def cell_call(self, row, col):
        entity = self.cw_rset.get_entity(row, col)
        _ = lambda ertype, form='': display_name(self._cw, ertype, form)
        reldata = []
        w = reldata.append
        if 'comments' in self._cw.vreg.schema and \
               'BlogEntry' in self._cw.vreg.schema.rschema('comments').objects():
            count = self._cw.execute('Any COUNT(C) WHERE C comments B, B eid %(x)s',
                                     {'x': entity.eid}, 'x')[0][0]
            if count:
                url = xml_escape(entity.absolute_url())
                w(u'<a href="%s">%s %s</a>' % (url, count, _('Comment', 'plural')))
            else:
                w(u'%s %s' % (count, _('Comment')))
        if 'tags' in self._cw.vreg.schema and \
               'BlogEntry' in self._cw.vreg.schema.rschema('tags').objects():
            tag_rset = entity.related('tags', 'object')
            if tag_rset:
                w(u'%s %s' % (_('tags', 'object'), self._cw.view('csv', tag_rset)))
        rset = entity.related('entry_of', 'subject')
        if rset:
            w(u'%s %s' % (self._cw._('blogged in '),
                          self._cw.view('csv', rset, 'null')))
        self.w(u' | '.join(reldata))


class BlogNavigation(navigation.PageNavigation):
    __select__ = paginated_rset() & sorted_rset() & implements('BlogEntry')

    def index_display(self, start, stop):
        return u'%s' % (int(start / self.page_size)+1)


# WFHistoryView ###############################################################

class BlogEntryWFHistoryVComponent(workflow.WFHistoryVComponent):
    __select__ = workflow.WFHistoryVComponent.__select__ & implements('BlogEntry')

    def cell_call(self, row, col, view=None):
        pass



# postcreate script. You could setup a workflow here for example

# BlogEntry workflow
bwf = add_workflow(_('default BlogEntry workflow'), 'BlogEntry')

draft = bwf.add_state(_('draft'), initial=True)
published = bwf.add_state(_('published'))

publish = bwf.add_transition(_('publish'), draft, published,
                             ('managers', 'owners'))




# pylint: disable-msg=W0622
"""cubicweb-blog packaging information"""

modname = 'blog'
distname = "cubicweb-%s" % modname

numversion = (1, 7, 3)
version = '.'.join(str(num) for num in numversion)

license = 'LGPL'

author = "Logilab"
author_email = "contact@logilab.fr"
web = 'http://www.cubicweb.org/project/%s' % distname

short_desc = "blogging component for the CubicWeb framework"
long_desc = """\
Summary
-------
The `blog` cube provides blogging functionnalities. It creates two entity types,
`Blog` and `BlogEntry`. There are related to each other by the relation
`BlogEntry entry_of Blog`.

Usage
-----

When a user submits a blog entry, it goes in a `draft` state until the blog
entry is published by an application managers. The blog entry will not be
visible until it reaches the `published` state.

When a blog entry is submitted, an email notification is automatically sent
to all the users belonging to the `managers` group of the application.

Specific boxes provided by this cube:

- `BlogEntryArchiveBox`, displays a box with the total number of blog entries
  submitted by month for the last twelve months.

- `BlogEntryListBox`, displays a box with the latest five blog entries
  published in your application as well as link to subscribe to a RSS feed.

- `BlogEntrySummary`, displays a box with the list of users who submitted
  blog entries and the total number of blog entries they submitted.

This cube also provides some web services such as:

- http://xx:xxxx/blogentries/YYYY to retrieve the blog entries submitted
  during the year YYYY through a RSS feed

- http://xx:xxxx/blogentries/YYYY/MM to retrieve the blog entries submitted
  during the month MM of the year YYYY through a RSS feed

- http://xx:xxxx/blog/[eid]/blogentries/YYYY to retrieve the blog entries
  submitted in the blog of identifier [eid], during the year YYYY through
  a RSS feed

- http://xx:xxxx/blog/[eid]/blogentries/YYYY/MM to retrieve the blog entries
  submitted in the blog of identifier [eid], during the month MM of the
  year YYYY through a RSS feed
"""

classifiers = [
    'Environment :: Web Environment'
    'Framework :: CubicWeb',
    'Programming Language :: Python',
    'Programming Language :: JavaScript',
    ]

__depends_cubes__ = {}
__depends__ = {'cubicweb': '>= 3.7.3'}
__use__ = tuple(__depends_cubes__)

# package ###

from os import listdir as _listdir
from os.path import join, isdir, exists
from glob import glob

THIS_CUBE_DIR = join('share', 'cubicweb', 'cubes', modname)

def listdir(dirpath):
    return [join(dirpath, fname) for fname in _listdir(dirpath)
            if fname[0] != '.' and not fname.endswith('.pyc')
            and not fname.endswith('~')
            and not isdir(join(dirpath, fname))]

data_files = [
    # common files
    [THIS_CUBE_DIR, [fname for fname in glob('*.py') if fname != 'setup.py']],
    ]
# check for possible extended cube layout
for dname in ('entities', 'views', 'sobjects', 'hooks', 'schema', 'data', 'i18n', 'migration'):
    if isdir(dname):
        data_files.append([join(THIS_CUBE_DIR, dname), listdir(dname)])
